Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/artemis_sg/__init__.py | 4 | 0 | 0 | 0 | 0 | 100%
src/artemis_sg/_version.py | 2 | 2 | 0 | 0 | 0 | 0%
src/artemis_sg/app_creds.py | 27 | 7 | 0 | 8 | 1 | 71%
src/artemis_sg/cli.py | 184 | 36 | 2 | 104 | 15 | 80%
src/artemis_sg/config/__init__.py | 49 | 26 | 0 | 22 | 2 | 44%
src/artemis_sg/gcloud.py | 65 | 49 | 2 | 12 | 0 | 21%
src/artemis_sg/img_downloader.py | 84 | 9 | 2 | 28 | 6 | 87%
src/artemis_sg/item.py | 45 | 2 | 0 | 14 | 3 | 92%
src/artemis_sg/items.py | 76 | 3 | 0 | 30 | 3 | 94%
src/artemis_sg/scraper.py | 623 | 84 | 0 | 94 | 28 | 83%
src/artemis_sg/slide_generator.py | 287 | 45 | 0 | 46 | 12 | 81%
src/artemis_sg/spreadsheet.py | 220 | 23 | 0 | 68 | 13 | 86%
src/artemis_sg/vendor.py | 22 | 3 | 0 | 2 | 1 | 83%
Total | 1688 | 289 | 6 | 428 | 84 | 80%

No items found using the specified filter.